@@ -24,5 +24,11 @@ module.exports = {
     ArraySetItem: 22,
     Array: 23,
     RetrieveArray: 24,
-    SetInstanceField: 25
+    SetInstanceField: 25,
+    InvokeGenericStaticMethod: 26,
+    InvokeGenericMethod: 27,
+    CreateGenericClassInstance: 28,
+    GetEnumItem: 29,
+    GetEnumName: 30,
+    GetEnumValue: 31
 }
\ No newline at end of file
