@@ -292,6 +292,40 @@ sub invoke_generic_method {
     );
 }
 
+#@override
+sub get_enum_name {
+    my ($self, @arguments) = @_;
+    my $command = Javonet::Sdk::Core::PerlCommand->new(
+        runtime      => $self->{runtime_name},
+        command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('GetEnumName'),
+        payload      => \@arguments
+    );
+    return Javonet::Sdk::Internal::InvocationContext->new(
+        $self->{runtime_name},
+        $self->{connection_type},
+        $self->{tcp_address},
+        $self->build_command($command),
+        0
+    );
+}
+
+#@override
+sub get_enum_value {
+    my ($self, @arguments) = @_;
+    my $command = Javonet::Sdk::Core::PerlCommand->new(
+        runtime      => $self->{runtime_name},
+        command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('GetEnumValue'),
+        payload      => \@arguments
+    );
+    return Javonet::Sdk::Internal::InvocationContext->new(
+        $self->{runtime_name},
+        $self->{connection_type},
+        $self->{tcp_address},
+        $self->build_command($command),
+        0
+    );
+}
+
 sub get_current_command {
     my $self = shift;
     return $self->{current_command};
